#
# spec file for package sensors
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#%%define   commit          1c48b191c8a2b9fc747e3db3816247c666c5c3f1
#%%define   shortcommit     1c48b19
%define   _name           lm-sensors
%define   _version        3-6-2
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           sensors
Version:        %(echo %{_version} | tr '-' '.')
Release:        3.1
Summary:        Hardware health monitoring for Linux
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://github.com/lm-sensors/%{_name}
Source0:        https://github.com/hramrach/%{_name}/archive/V%{_version}.tar.gz#/%{_name}-%{_version}.tar.gz
Source1:        sysconfig.sensord
Source2:        baselibs.conf
Patch1:         lm_sensors-3.1.1-build.patch
Patch2:         lm_sensors-3.0.0-sensord-separate.patch
Patch3:         lm_sensors-3.0.0-sysconfig_metadata.patch
Patch4:         lm_sensors-3.0.3-hint-at-kernel-extra-package.patch
Patch8:         lm_sensors-3.5.0-libsensors-fix-soname.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  perl-Test-Cmd
BuildRequires:  rrdtool-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  valgrind
Requires:       modutils
%{?systemd_requires}

%description
This package includes programs that show data from some sensor chips.
The interface /proc/bus/i2c/ is provided by loading kernel modules.
Which modules to load can be interactively detected as root by calling
%{_sbindir}/sensors-detect. Warning, before using the sensors the default
configuration in %{_sysconfdir}/sensors.conf has to be checked and changed to fit
the actual set up of the mainboard and the BIOS used on that specific
mainboard!

%package -n sensord
Summary:        Hardware health monitoring daemon
License:        GPL-2.0-or-later
Group:          System/Monitoring
Requires(pre):  %fillup_prereq
Provides:       sensors:%{_sbindir}/sensord

%description -n sensord
sensord is a daemon that can be used to periodically log sensor
readings from hardware health-monitoring chips to the system logs or a
round-robin database (RRD) and to alert when a sensor alarm is
signalled; for example, if a fan fails, a temperature limit is
exceeded, etc.

%package -n libsensors4
Summary:        Hardware health monitoring library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libsensors4
libsensors offers a way for applications to access the hardware
monitoring chips of the system. A system-dependent configuration file
controls how the different inputs are labeled and what scaling factors
have to be applied for the specific hardware, so that the output makes
sense to the user.

%package -n libsensors4-devel
Summary:        Hardware health monitoring library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libsensors4 = %{version}
Provides:       sensors:%{_includedir}/sensors/sensors.h

%description -n libsensors4-devel
libsensors offers a way for applications to access the hardware
monitoring chips of the system. A system-dependent configuration file
controls how the different inputs are labeled and what scaling factors
have to be applied for the specific hardware, so that the output makes
sense to the user.

%prep
%autosetup -p1 -n %{_name}-%{_version}

%build
RPM_OPT_FLAGS="%{optflags}"
make %{?_smp_mflags} PROG_EXTRA:=sensord BUILD_STATIC_LIB:=0 PREFIX=%{_prefix} MANDIR=%{_mandir} LIBDIR=%{_libdir}

%install
    make PROG_EXTRA:=sensord BUILD_STATIC_LIB:=0 PREFIX=%{_prefix} MANDIR=%{_mandir} LIBDIR=%{_libdir} DESTDIR=%{buildroot} install
    mkdir -p				%{buildroot}/%{_docdir}/sensors %{buildroot}/%{_docdir}/sensord
    cp -a doc/donations doc/fan-divisors \
	  doc/fancontrol.txt doc/libsensors-API.txt \
	  doc/progs doc/temperature-sensors \
	  doc/vid COPYING COPYING.LGPL	%{buildroot}/%{_docdir}/sensors/
    cp -a COPYING			%{buildroot}/%{_docdir}/sensord/
    chmod -R u+rwX,g+rX,o+rX		%{buildroot}/%{_docdir}/sensors/ %{buildroot}/%{_docdir}/sensord/
    chmod 0755 %{buildroot}/%{_libdir}/libsensors.so.*
    mkdir -p				%{buildroot}/%{_unitdir} %{buildroot}/%{_fillupdir}
    cp -a prog/init/*.service 		%{buildroot}/%{_unitdir}/
    ln -sf service			%{buildroot}%{_sbindir}/rclm_sensors
    ln -sf service			%{buildroot}%{_sbindir}/rcfancontrol
    ln -sf service			%{buildroot}%{_sbindir}/rcsensord
    cp -a %{SOURCE1}			%{buildroot}/%{_fillupdir}

%check
make test

%pre
%service_add_pre lm_sensors.service fancontrol.service

%post
sh -c '
CONFIG=%{_sysconfdir}/sysconfig/lm_sensors
test -r "$CONFIG" || exit 0
unset ${!MODULE_*} $HWMON_MODULES
. "$CONFIG"
test -n "$HWMON_MODULES" && exit 0
for i in ${!MODULE_*} ; do
        eval module=\$$i
        if test -z "$HWMON_MODULES" ; then
                HWMON_MODULES="$module"
        else
                HWMON_MODULES="$HWMON_MODULES $module"
        fi
done
test -z "$HWMON_MODULES" && exit 0
echo >> "$CONFIG"
echo "# New configuration format generated by rpm post-install script" >> "$CONFIG"
echo "HWMON_MODULES=\"$HWMON_MODULES\"" >> "$CONFIG"
'
if test -e %{_sysconfdir}/modprobe.d/lm_sensors -a ! -e %{_sysconfdir}/modprobe.d/lm_sensors.conf ; then
	mv -f %{_sysconfdir}/modprobe.d/lm_sensors %{_sysconfdir}/modprobe.d/lm_sensors.conf
fi
%service_add_post lm_sensors.service fancontrol.service

%preun
%service_del_preun fancontrol.service lm_sensors.service

%postun
%service_del_postun fancontrol.service lm_sensors.service

%pre -n sensord
%service_add_pre sensord.service

%post -n sensord
%service_add_post sensord.service
%{fillup_only -n sensord}

%preun -n sensord
%service_del_preun sensord.service

%postun -n sensord
%service_del_postun sensord.service

%post -n libsensors4 -p /sbin/ldconfig
%postun -n libsensors4 -p /sbin/ldconfig

%files
%{_unitdir}/lm_sensors.service
%{_sbindir}/rclm_sensors
%{_unitdir}/fancontrol.service
%{_sbindir}/rcfancontrol
%{_bindir}/*
%{_sbindir}/fancontrol
%ifarch i386 i486 i586 i686 x86_64
%{_sbindir}/isadump
%{_sbindir}/isaset
%endif
%{_sbindir}/pwmconfig
%{_sbindir}/sensors-detect
%dir %{_docdir}/sensors
%doc %{_docdir}/sensors/donations
%doc %{_docdir}/sensors/fan-divisors
%doc %{_docdir}/sensors/fancontrol.txt
%doc %{_docdir}/sensors/progs
%doc %{_docdir}/sensors/temperature-sensors
%doc %{_docdir}/sensors/vid
%license %{_docdir}/sensors/COPYING
%{_mandir}/man1/*.1%{?ext_man}
%{_mandir}/man8/fancontrol.8%{?ext_man}
%ifarch i386 i486 i586 i686 x86_64
%{_mandir}/man8/isadump.8%{?ext_man}
%{_mandir}/man8/isaset.8%{?ext_man}
%endif
%{_mandir}/man8/pwmconfig.8%{?ext_man}
%{_mandir}/man8/sensors-conf-convert.8%{?ext_man}
%{_mandir}/man8/sensors-detect.8%{?ext_man}
%{_datadir}/zsh/site-functions/

%files -n sensord
%{_unitdir}/sensord.service
%{_sbindir}/rcsensord
%{_fillupdir}/sysconfig.sensord
%{_sbindir}/sensord
%dir %{_docdir}/sensord
%license %{_docdir}/sensord/COPYING
%{_mandir}/man8/sensord.8%{?ext_man}

%files -n libsensors4
%config %{_sysconfdir}/sensors3.conf
%config %{_sysconfdir}/sensors.d/
%{_libdir}/libsensors.so.4*
%dir %{_docdir}/sensors
%license %{_docdir}/sensors/COPYING.LGPL
%{_mandir}/man5/*.5%{?ext_man}

%files -n libsensors4-devel
%{_includedir}/sensors/
%{_libdir}/libsensors.so
%dir %{_docdir}/sensors
%doc %{_docdir}/sensors/libsensors-API.txt
%{_mandir}/man3/*.3%{?ext_man}

%changelog
* Mon Aug 12 2024 Martin Jambor <mjambor@suse.com>
- Drop lm_sensors-revert-6b5a19b708.patch because the previously
  incompatible types have been changed in the callee in package
  rrdtool too, which means that there is a type incompatibility again.
  Because the other change reportedly makes more sense, I'm dropping
  this one.
* Mon Jul 22 2024 Martin Jambor <mjambor@suse.com>
- Add lm_sensors-revert-6b5a19b708.patch which reverts an upstream
  patch, thus adding back two explicit pointer type-casts.  Code
  without them used to generate mere warnings until this year but
  causes compiler errors with GCC 14 by default.
* Sat Jan 13 2024 Michal Suchanek <msuchanek@suse.com>
- Update to version 3.6.2:
  * sensor quantitiy and units
  * new json format
  * SENSORS_SYSFS_ROOT environment variable
  * service files updated
- Drop upstreamed patches
  * harden_fancontrol.service.patch
  * harden_lm_sensors.service.patch
  * harden_sensord.service.patch
  * lm_sensors-3.4.0-sensord-service-extra-args.patch
  * var-run-deprecated.patch
  * rrd-drop-useless-cast.patch
  * pwmconfig-raise-fan-threshold.patch
  * sysfs-Expand-filename-buffer-to-quiet-warning.patch
- Run tests
* Mon Dec 25 2023 Michal Suchanek <msuchanek@suse.com>
- Update to version 3.6.1:
  * configs: Added a number of new configuration files
  * fancontrol: Add executable commands as temp sensors
  * pwmconfig, fancontrol: Allow read-only pwm*_enable
  * sensors: Handle json trailing ',' when no features are listed
    Add support for rated values
    Only do conversion to Fahrenheit on temperatures
  * sensors-detect: Add support for NCT6687D
    Add support for AMD CPU Family 19h
    Add support for FTS Teutates Chip
    Fix the driver for Nuvoton W83677HG-I
  * sensord: Add support of emergency alarm
    Change PIDFile path from /var/run to /run
  * Allow subfeatures to be ignored too
  * Flag allow-no-sensors added
  * Add support for dev_name formatted like "a000000.wifi"
  * Add ZSH completion for sensors and sensors-detect
  * Add ISA ACPI sensor driver name support
  * Add support for static only build
  * Add SDIO attached sensor support
  * Add PWM and frequency sensor support
- Drop trailing space from hardedning patches
  * harden_fancontrol.service.patch
  * harden_lm_sensors.service.patch
  * harden_sensord.service.patch
- Refresh
  * lm_sensors-3.4.0-sensord-service-extra-args.patch
  * var-run-deprecated.patch
- Add rrd-drop-useless-cast.patch
- Drop usptreamed patches
  * change-pidfile-path-from-var-run-to-run.patch
  * lm_sensors-3.4.0-sensors-detect-add-ftsteutates-support.patch
  * lm_sensors-3.6.0-sensors-detect-fix-driver-for-w83677hgi.patch
  * pwmconfig-handle-fan-input-error.patch
- Drop obsolete spec file constructs, use autopatch.
* Mon Dec 13 2021 Johannes Segitz <jsegitz@suse.com>
- Also remove ProtectKernelTunables from harden_fancontrol.service.patch,
  breaks service (boo#1193149)
* Mon Nov 29 2021 Johannes Segitz <jsegitz@suse.com>
- Remove ProtectKernelTunables from harden_lm_sensors.service.patch,
  breaks service (boo#1193149)
* Tue Nov 16 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_fancontrol.service.patch
  * harden_lm_sensors.service.patch
  * harden_sensord.service.patch
* Fri Aug 20 2021 Jan Engelhardt <jengelh@inai.de>
- Trim ExcludeArch, package build is successful.
* Mon Apr 26 2021 Jean Delvare <jdelvare@suse.com>
- change-pidfile-path-from-var-run-to-run.patch: Change PIDFile
  path from /var/run to /run (bsc#1185183).
- var-run-deprecated.patch: /var/run is deprecated (bsc#1185183).
* Thu Feb 11 2021 Jean Delvare <jdelvare@suse.com>
- pwmconfig-handle-fan-input-error.patch: pwmconfig: Deal
  gracefully with unreadable fan inputs (boo#1181890).
- pwmconfig-raise-fan-threshold.patch: pwmconfig: Further raise the
  fan threshold (boo#1181890).
* Tue May 12 2020 Jean Delvare <jdelvare@suse.com>
- lm_sensors-3.6.0-sensors-detect-fix-driver-for-w83677hgi.patch:
  Point owners of Nuvoton W83677HG-I and compatible chipsets to
  the nct6775 driver, as support was just removed from the
  w83627ehf driver (bsc#1169316).
* Tue Dec  3 2019 Samu Voutilainen <smar@smar.fi>
- Removed upstreamed patch lm_sensors-3.4.0-sensors-detect-ppc64le.patch
- Update to version 3.6.0:
  + configs: Added a number of new configuration files
  + fancontrol: AVERAGE env variable can be used to set the number of previous readings to average
  + Makefile: The MACHINE variable has been renamed to ARCH
  + sensord: Add an option -1/--oneline to print chip and adapter on the same line
  + sensors: Fixed a stray comma bug in the JSON output
  * Fixed Fahrenheit conversion with raw and JSON output
  * Scale voltage and current values in the default output format
  + sensors-detect: Add detection of AMD Family 17h, models 30h, 70h
  * Add detection of some AMD Family 15h models
  * Add detection of AMD Family 16h model 30h power sensors
  * Add detection of Hygon Family 18h thermal sensors
  * Add detection of Nuvoton NCT6797D
  * Add detection of Nuvoton NCT6798D
  * Add detection of Nuvoton NCT6112D/NCT6114D/NCT6116D
  * Fix printing CPU info on non-x86 arches
  * Fix printing lm_sensors version
  * Mark Fintek F75387SG/RG as supported by the f75375s driver
* Sun Mar  3 2019 Jan Engelhardt <jengelh@inai.de>
- Join %%service_* lines to generate less scriptlet boilerplate.
* Wed Dec 19 2018 jdelvare@suse.com
- lm_sensors-3.5.0-libsensors-fix-soname.patch: Undo the
  SENSORS_API_VERSION change, to stay source-compatible with
  upstream.
* Sun Dec 16 2018 jdelvare@suse.com
- lm_sensors-3.5.0-libsensors-fix-soname.patch: Undo excessive
  libsensors version bump.
* Sat Nov 24 2018 malcolmlewis@opensuse.org
- Update to version 3.5.0:
  + soname was bumped due to commit dcf2367 which introduced an
    ABI change.
  + Fixed disappearance of certain hwmon chips with 4.19+ kernels,
    (gh#lm-sensors/lm-sensors#139, boo#1116021).
  + Add the find-driver script for debugging.
  + Various documentation and man page improvements.
  + Fix various issues found by Coverity Scan.
  + Fix compilation with the musl C library.
  + Updated links in documentation to reflect the new home of
    lm_sensors.
  + sensors.1: Add reference to sensors-detect and document -j
    option (json output).
  + sensors: Add support for json output, add support for power
    min, lcrit, min_alarm, lcrit_alarm.
  + sensors-detect:
  * Fix systemd paths.
  * Add detection of Fintek F81768.
  * Only probe I/O ports on x86.
  * Add detection of Nuvoton NCT6793D.
  * Add detection of Microchip MCP9808.
  * Mark F71868A as supported by the f71882fg driver.
  * Mark F81768D as supported by the f71882fg driver.
  * Mark F81866D as supported by the f71882fg driver.
  * Add detection of various ITE chips.
  * Add detection of Nuvoton NCT6795D.
  * Add detection of DDR4 SPD.
  * Add detection of ITE IT8987D.
  * Add detection of AMD Family 17h temperature sensors.
  * Add detection of AMD KERNCZ SMBus controller.
  * Add detection of various Intel SMBus controllers.
  * Add detection of Giantec GT30TS00.
  * Add detection of ONS CAT34TS02C and CAT34TS04.
  * Add detection of AMD Family 15h Model 60+ temperature
    sensors.
  * Add detection of Nuvoton NCT6796D.
  * Add detection of AMD Family 15h Model 70+ temperature
    sensors.
  + configs: Add sample configuration files.
  + sensors.conf.default:
  * Add hardwired inputs of NCT6795D
  * Add hardwired inputs of F71868A
  * Add hardwired NCT6796D inputs
  + vt1211_pwm: replaced deprecated sub shell syntax, run with
    bash instead of sh.
  + pwmconfig: replaced deprecated sub shell syntax.
  + fancontrol: replaced deprecated sub shell syntax, save
    original pwm values.
  + fancontrol.8: replaced deprecated sub shell syntax.
  + libsensors:
  * Add support for SENSORS_BUS_TYPE_SCSI, add support
    for power min, lcrit, min_alarm, lcrit_alarm.
  * Handle hwmon device with thermal device parent (bsc#1108468).
- Rebase lm_sensors-3.0.3-hint-at-kernel-extra-package.patch for
  new release.
- Spec file tidy up for man page extension.
* Mon May 14 2018 hillwood@opensuse.org
- Update version to 3.4.0git20180510.1c48b19, use git version
  * Support many new hardware:
    + Add detection of Fintek F81768
    + Only probe I/O ports on x86
    + Add detection of Nuvoton NCT6793D
    + Add detection of Microchip MCP9808
    + Mark F71868A as supported by the f71882fg driver
    + Mark F81768D as supported by the f71882fg driver
    + Mark F81866D as supported by the f71882fg driver
    + Add detection of various ITE chips
    + Add detection of Nuvoton NCT6795D
    + Add detection of DDR4 SPD
    + Add detection of ITE IT8987D
    + Add detection of AMD Family 17h temperature sensors
    + Add detection of AMD KERNCZ SMBus controller
    + Add detection of various Intel SMBus controllers
    + Add detection of Giantec GT30TS00
    + Add detection of ONS CAT34TS02C and CAT34TS04
    + Add detection of AMD Family 15h Model 60+ temperature sensors
    + Add detection of Nuvoton NCT6796D
    + Add detection of AMD Family 15h Model 70+ temperature sensors
  * Fix syntax errors
  * Fix systemd paths
- Drop lm_sensors-3.4.0-sensors-detect-fix-systemd-path.patch
  Upstream merge this patch
- Drop lm_sensors-3.4.0+-Only-probe-I-O-ports-on-x86.patch
  Upstream merge this patch
- Change upstream url.
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Nov 30 2016 jdelvare@suse.com
- lm_sensors-3.4.0+-Only-probe-I-O-ports-on-x86.patch: Skip
  "random" I/O port probing on non-x86 machines (bsc#1008552)
* Wed Oct  5 2016 jdelvare@suse.com
- lm_sensors-3.4.0-sensors-detect-ppc64le.patch: Fix sensors-detect
  CPU detection support on ppc architectures (bsc#999987)
* Fri Sep  2 2016 sweet_f_a@gmx.de
- add lm_sensors-3.4.0-sensors-detect-add-ftsteutates-support.patch
  for ftsteutates support (Fujitsu Skylake boards)
* Sun Jan 31 2016 jdelvare@suse.com
- lm_sensors-3.4.0-sensord-service-extra-args.patch: Allow passing
  arbitrary extra arguments to sensord.
* Thu Jul  2 2015 jdelvare@suse.com
- lm_sensors-3.4.0-sensors-detect-fix-systemd-path.patch: Handle
  the move of systemd from / to /usr.
* Tue Jun 30 2015 jdelvare@suse.com
- Update to lm_sensors 3.4.0
  * library: The arbitrary limit on per-type sensor count is gone.
    Support for temperature min and critical min hysteresis.
  * sensors: Support for temperature min and critical min
    hysteresis.
  * fancontrol: Deal with moving hwmon attributes. Reduce memory
    consumption.
  * sensors-detect: Detection of new devices.
  * lm_sensors-r6216-fancontrol-moving-hwmon-attributes.patch,
    lm_sensors-r6237-default-config-NCT6779-NCT6791.patch,
    lm_sensors-r6254-detect-print-kernel-cpu.patch,
    lm_sensors-r6255-fix-shell-error-FCFANS.patch,
    lm_sensors-r6282-detect-graphics-card-in-all-cases.patch,
    lm_sensors-r6283-skip-addresses-0x37-0x4f-on-DDC.patch:
    Removed, upstream now.
  * lm_sensors-3.0.0-sensord-separate.patch,
    lm_sensors-3.0.0-sysconfig_metadata.patch,
    lm_sensors-3.0.3-hint-at-kernel-extra-package.patch: Refreshed.
* Tue Jun  9 2015 jdelvare@suse.com
- lm_sensors-r6282-detect-graphics-card-in-all-cases.patch:
  sensors-detect: Detect graphics card in all cases (bsc#933072).
- lm_sensors-r6283-skip-addresses-0x37-0x4f-on-DDC.patch:
  sensors-detect: Skip addresses 0x37 and 0x4f on DDC channels
  (bsc#933072).
* Wed Nov  5 2014 jdelvare@suse.com
- lm_sensors-r6216-fancontrol-moving-hwmon-attributes.patch:
  fancontrol: Deal with moving hwmon attributes.
- lm_sensors-r6237-default-config-NCT6779-NCT6791.patch:
  sensors.conf.default: Add support for NCT6779 and NCT6791.
- lm_sensors-r6254-detect-print-kernel-cpu.patch: Print kernel
  version and processor information.
- lm_sensors-r6255-fix-shell-error-FCFANS.patch: fancontrol: Fix
  shell error when FCFANS is not set (bnc#903520).
* Thu Jul  3 2014 jdelvare@suse.com
- Actually create the sensord service configuration file from the
  template (bnc#882719).
* Wed Jul  2 2014 jdelvare@suse.com
- Add pre/post hooks for sensord service.
- Add sysconfig template for sensord service (bnc#882719).
* Tue Jan 28 2014 jdelvare@suse.de
- Package COPYING and COPYING.LGPL.
* Wed Jan 22 2014 jdelvare@suse.de
- Package new file /usr/share/man/man8/sensors-conf-convert.8.gz.
* Wed Jan 22 2014 jdelvare@suse.de
- Update to lm_sensors 3.3.5
  * library: Support up to 33 sensors of the same type per
    monitoring chip (needed for recent Intel processors, coretemp
    driver)
  * sensors-detect: Detection of new devices
    Added non-interactive (automatic) mode
  * lm_sensors-r6181-fix-service-files.patch: Removed, upstream
    now.
  * lm_sensors-3.0.0-sysconfig_metadata.patch,
    lm_sensors-3.0.3-hint-at-kernel-extra-package.patch: Refreshed.
* Wed Oct 23 2013 p.drouand@gmail.com
- Remove sysvinit support; none of target distributions use it anymore
* Mon Jul  1 2013 coolo@suse.com
- sensors is required for pacemaker and libdlm, and as such
  we should not buildrequire systemd
* Mon Jun  3 2013 jdelvare@suse.de
- Update to lm_sensors 3.3.4
  * Mostly a packaging-only clean-up, as we had backported most
    important changes already.
  * lm_sensors-r6111-detection-Winbond-W83627SF.diff,
    lm_sensors-r6112-detection-AMD-family-16h.diff,
    lm_sensors-r6113-ITE-IT877x-IT878x-driver.diff,
    lm_sensors-r6117-detection-ITE-IT8752F.diff,
    lm_sensors-r6123-AnalogDev-ADT7410-driver.diff,
    lm_sensors-r6163-pwmconfig-raise-threshold.diff,
    lm_sensors-r6164-pwmconfig-drop-comment.diff,
    lm_sensors-r6165-pwmconfig-multiple-fans.diff,
    lm_sensors-r6172-fancontrol-absolute-paths.diff: Removed,
    upstream now.
  * fancontrol.service: Removed, now provided by upstream,
    together with sensord.service.
  * lm_sensors-3.0.0-sysconfig_metadata.patch,
    lm_sensors-3.0.3-hint-at-kernel-extra-package.patch: Refreshed.
- lm_sensors-r6181-fix-service-files.patch: Fix EnvironmentFile
  in service files
* Thu May 23 2013 jdelvare@suse.de
- lm_sensors-r6163-pwmconfig-raise-threshold.diff: pwmconfig: Raise
  the detection threshold to 3/4 (bnc#810344).
- lm_sensors-r6164-pwmconfig-drop-comment.diff: pwmconfig: Drop a
  stray comment.
- lm_sensors-r6165-pwmconfig-multiple-fans.diff:  pwmconfig:
  Properly deal with multiple fan control (bnc#810344).
- lm_sensors-r6172-fancontrol-absolute-paths.diff: fancontrol: Fix
  handling of absolute paths in config (bnc#810344).
* Thu May 23 2013 jdelvare@suse.de
- fancontrol.service: Cleanups.
* Sat May 18 2013 werner@suse.com
- Add fancontrol.service (bnc#810344).
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Thu Feb 28 2013 jdelvare@suse.de
- lm_sensors-r6111-detection-Winbond-W83627SF.diff: Add detection
  of Winbond W83627SF/GF (no sensors.)
- lm_sensors-r6112-detection-AMD-family-16h.diff: Add detection of
  AMD family 16h power sensors.
- lm_sensors-r6113-ITE-IT877x-IT878x-driver.diff: Map IT8771E,
  IT8772E, IT8782F and IT8783F to it87.
- lm_sensors-r6117-detection-ITE-IT8752F.diff: Add detection of
  IT8752F.
- lm_sensors-r6123-AnalogDev-ADT7410-driver.diff: We have a driver
  for the ADT7410 since kernel 3.7.
* Fri Nov  9 2012 hrvoje.senjan@gmail.com
- Update to lm_sensors 3.3.3
  * documentation: Update fan-divisors, fan divisors are optional
  * libsensors: Fix warning about library path not in /etc/ld.so.conf
  * sensors: Fix libiconv linkage need detection in rare corner case
    Add support for humidity output
    Add long switches to manual page
  * sensors-detect: Don't choke on systems without PCI
    Avoid probing EDID addresses on graphics cards (#2386)
    Add detection of NCT6779D and NCT6102D/NCT6106D
    Add detection of SMSC LPC47N217 and SIO10N268
    Do not scan I2C adapters on graphics cards by default
    Fix parent class discovery when multiplexer is present
* Thu Nov  1 2012 crrodriguez@opensuse.org
- lm_sensors systemd service file missing [bnc#768354]
* Thu Sep 13 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Use the "modutils" require instead of "modules" to select a
  module toolset implementation
* Tue Mar 20 2012 jdelvare@suse.de
- Update to lm_sensors 3.3.2
  * Support for many subfeatures implemented by new hwmon drivers.
  * Fix to support a sysfs implementation change in upcoming kernels.
  * Better printing of power sensors in sensors.
  * Memory leaks fixed in sensord.
  * New chips known by sensors-detect, as usual.
- lm_sensors-r5991-improve-filtering-of-fake-DMI-data.patch,
  lm_sensors-r5992-print-DMI-product-version.patch,
  lm_sensors-r5993-fix-loading-of-cpuid-module.patch,
  lm_sensors-r6016-handle-superio-wo-logdev.patch,
  lm_sensors-r6017-fix-sysfs-detection.patch,
  lm_sensors-r6025-sensord-fix-memory-leaks.patch,
  lm_sensors-r6030-fix-power-interval-output.patch: Removes,
  obsolete.
* Thu Mar  8 2012 jdelvare@suse.de
- lm_sensors-r5993-fix-loading-of-cpuid-module.patch: Fix loading
  of the cpuid module.
- lm_sensors-r6016-handle-superio-wo-logdev.patch: Properly handle
  Super-I/O chips without logical device.
- lm_sensors-r6017-fix-sysfs-detection.patch: libsensors: Change
  sysfs detection to survive upcoming kernel changes (bnc#751180).
- lm_sensors-r6025-sensord-fix-memory-leaks.patch: sensord: Fix
  memory leaks revealed by valgrind (bnc#751177).
- lm_sensors-r6030-fix-power-interval-output.patch: Fix power
  interval output.
* Tue Jan 17 2012 jdelvare@suse.de
- Package /etc/sensors.d/.
* Thu Sep 22 2011 jdelvare@suse.de
- lm_sensors.init: Move lock file from /var/lock/subsys to
  /var/run (bnc#714654).
* Fri Jul 22 2011 jdelvare@suse.de
- Update to lm_sensors 3.3.1
  * Detection of new devices
- lm_sensors-3.1.1-no-ipmisensors-driver.patch: Removed, obsolete.
- lm_sensors-r5991-improve-filtering-of-fake-DMI-data.patch,
  lm_sensors-r5992-print-DMI-product-version.patch: Improve DMI
  product identification.
* Tue Mar 29 2011 jdelvare@suse.de
- Update to lm_sensors 3.3.0
  * Support for chassis intrusion and humidity sensors
  * Support for many new attributes
  * Detection of new devices
- lm_sensors-r5952-new-fintek-chips.patch: Fix driver mapping of
  two new Fintek chips.
* Thu Feb 17 2011 jdelvare@suse.de
- lm_sensors-r5930-fix-DDR3-SPD-detection.patch: Fix typo in
  comparison.
* Thu Feb 17 2011 jdelvare@suse.de
- lm_sensors-r5910-detect-new-Nuvoton-superio.patch: Add detection
  of Nuvoton NCT5571D, NCT5577D and NCT6776F.
- lm_sensors-r5913-default-config-NCT677xF.patch: Default config
  for NCT6775F and NCT6776F.
- lm_sensors-r5914-fix-TMP421-detection.patch: We probe addresses
  0x1c-0x1f for other chips now, so we might as well look for
  TMP421 devices there.
- lm_sensors-r5916-fix-EMC140x-detection.patch: Fix addresses
  checked for SMSC EMC1403 and EMC1404.
- lm_sensors-r5930-fix-DDR3-SPD-detection.patch: Fix detection of
  SPD EEPROM on DDR3 memory modules. DDR3 uses CRC16 over 128 bytes
  instead of basic checksum over 64 bytes. Contributed by Clemens
  Ladisch.
- libensors-visibility.patch: Add 3 missing symbols.
* Wed Jan 19 2011 jdelvare@suse.de
- lm_sensors-r5870-i2c-non-sequential.patch: Fix error seen in
  sensors-detect if i2c bus numbering is not sequential.
- lm_sensors-r5883-W83667HG-B-is-supported.patch: The W83667HG-B is
  supported by the w83627ehf driver since kernel 2.6.36.
- lm_sensors-r5886-default-config-W83627THF.patch: Add a default
  configuration section for the Winbond W83627THF.
- lm_sensors-r5887-typo-in-sensors-conf-5.patch: Fixed typo in
  lib/sensors.conf.5.
- lm_sensors-r5889-default-config-SCH5127.patch: Add a default
  configuration section for the SMSC SCH5127.
- lm_sensors-r5905-fix-coretemp-detection.patch: Implement
  universal detection for Intel digital thermal sensors.
* Mon Nov 29 2010 cristian.rodriguez@opensuse.org
- libsensors: export only public symbols
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon Oct 11 2010 jdelvare@suse.de
- Update to lm_sensors 3.2.0
  * The libsensors library is now released under the LGPL license
  * Minor fixes to libsensors, pwmconfig, sensors and sensord
  * New chips known by sensors-detect, as usual
- Don't build the static library in the first place, so we don't
  have to delete it later.
* Tue Jun  1 2010 jdelvare@suse.de
- lm_sensors-r5837-fix-fam10-RB-C3-detection.patch: Fix detection
  of RB-C3 AMD Family 10h CPU.
* Fri May  7 2010 jdelvare@suse.de
- lm_sensors-r5835-fix-sensord-regression.patch: Fix regression
  in sensord (support for multiple chips was broken by release
  3.1.2). Fixes upstream ticket #2377.
* Tue Apr 13 2010 jdelvare@suse.de
- Properly implement "rclm_sensors status" (bnc#592273).
* Wed Mar 31 2010 jdelvare@suse.de
- lm_sensors-r5832-adt7468-driver.patch: The ADT7467/8 is supported
  by the lm85 driver since kernel 2.6.28.
* Thu Feb  4 2010 jdelvare@suse.de
- Update to lm_sensors 3.1.2
  * Support for future kernels and HID devices in libsensors
  * Cleanups to sensord
  * New chips known by sensors-detect, as usual
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel build
* Fri Dec  4 2009 jdelvare@suse.de
- lm_sensors-3.1.1-no-ipmisensors-driver: Do not point the user to
  the ipmisensors driver which we do not ship (bnc#558756).
* Wed Oct 28 2009 crrodriguez@opensuse.org
- devel package must require glibc-devel
* Wed Sep 16 2009 jdelvare@suse.de
- lm_sensors-r5770-fancontrol-update.patch: Make fancontrol more
  robust to kernel driver changes (bnc#529483).
* Fri Jul 24 2009 jdelvare@suse.de
- lm_sensors-r5757-LPC47M233-not-supported.patch: Don't point the
  user at a driver which will not work.
- lm_sensors-r5760-rename-modprobe-conf.patch: Properly name
  the modprobe configuration file.
* Mon Jul 20 2009 jdelvare@suse.de
- Update to lm_sensors 3.1.1
  * Completely reworked sensors-detect
  * Support for multiple configuration files
  * New default sensors.conf file
  * add lm_sensors-3.1.1-build.patch
- Include our own init script instead of patching upstream's to no
  end.
- Fix init script Provides (lm_sensors instead of sensors.)
  (bnc#487479)
- Fix init script lock file name.
- Stop patching prog/init/README, we no longer distribute it.
- /etc/sensors3.conf can be updated, user changes should no longer
  go there.
* Sat Apr 18 2009 crrodriguez@suse.de
- remove static libraries
* Sun Jan 11 2009 jdelvare@suse.de
- lm_sensors-r5473-sensord-negative-temperatures-in-RRD.patch:
  Accept negative temperatures in RRD database.
- lm_sensors-r5580-sensord-survive-transient-errors.patch: Don't
  bail out on transient errors.
- lm_sensors-r5581-fix-libsensors-error-propagation.patch: Fix
  error propagation during expression evaluation.
- Add %%stop_on_removal to the %%preun script (fixes an RPMlint
  warning.)
* Wed Oct 22 2008 jdelvare@suse.de
- lm_sensors-r5366-fix-detection-of-Intel-AMB.patch: Fix detection
  of Intel 5000 series FB-DIMM AMB.
* Tue Oct 14 2008 jdelvare@suse.de
- lm_sensors-r5352-fix-detection-of-ADT7463-and-LM96000.patch: Fix
  detection of ADT7463 and LM96000.
- lm_sensors-3.0.3-hint-at-kernel-extra-package.patch: Now that the
  kernel package is split into 3 parts, it is possible that not all
  required hwmon drivers are installed on the system when
  sensors-detect is being run. Point the user to the kernel-*-extra
  package if drivers are found to be missing. (bnc#431555)
* Sun Sep 28 2008 jdelvare@suse.de
- Update to lm_sensors 3.0.3
  * Many improvements to pwmconfig
  * sensors-detect knows of a dozen additional devices and was made
    more reliable for another half dozen
* Sun May 18 2008 jdelvare@suse.de
- Update to lm_sensors 3.0.2
  * Support for virtual hardware monitoring devices
  * Support for power and energy sensors
  * Safer sensors-detect
  * FAQ is gone
* Mon May 12 2008 jdelvare@suse.de
- lm_sensors-r5235-dont-probe-I2C-addr-40-47.patch: Don't probe I2C
  addresses 0x40-0x47.
- lm_sensors-r5245-skip-1-reg-only-I2C-devs.patch: Detect and skip
  1-register-only I2C devices.
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Tue Apr 29 2008 cthiel@suse.de
- fix baselibs.conf
- obsolete sensors-<arch> via baselibs.conf
* Wed Apr 16 2008 jdelvare@suse.de
- lm_sensors-r5169-parse-config-in-C-locale.patch: Parse the
  configuration file in C locale.
- lm_sensors-r5175-compute-statements-override.patch: Late compute
  statements should override early ones.
- lm_sensors-ignore-missing-device-link.patch: Don't choke on
  hwmon devices with no device link. The new thermal zone code that
  went into kernel 2.6.25-rc5-git4 creates one such hwmon device.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Mar 13 2008 werner@suse.de
- Remove hard coded loading of i2c-dev or better i2c-core as it
  should happen due auto dependcies (bnc#369798)
* Mon Feb  4 2008 jdelvare@suse.de
- Update to lm_sensors 3.0.1
  * Library no longer depends on libsysfs
  * Library initialization is much faster
  * Better service integration in sensors-detect
* Sat Jan 19 2008 jdelvare@suse.de
- Pass PREFIX and MANDIR on the command line from the spec file
  rather than patching the Makefile. This is easier to maintain.
* Tue Dec 18 2007 jdelvare@suse.de
- Fix voltage references in sensors.conf. Fixed upstream in:
  http://www.lm-sensors.org/changeset/5076
* Tue Dec 11 2007 jdelvare@suse.de
- Fix rrd support in sensord. Fixed upstream in:
  http://www.lm-sensors.org/changeset/5069
* Fri Nov 30 2007 jdelvare@suse.de
- Remove obsolete Requires tags. Since version 3.0.0, it is no
  longer mandatory to provide a configuration file to libsensors.
* Thu Nov 29 2007 jdelvare@suse.de
- Add missing Conflicts tag.
* Tue Nov 27 2007 jdelvare@suse.de
- Add a link to the init script.
* Mon Nov 26 2007 jdelvare@suse.de
- Update to lm_sensors version 3.0.0
  * Completely rewritten library, much smaller
  * Supports all devices supported by the kernel (contains no
    device-specific code)
  * libsensors has a new SONAME (libsensors.so.4)
  * fancontrol.pl is gone
  * Add lm_sensors-3.0.0-sensord-separate.patch lm_sensors-3.0.0-sysconfig_metadata.patch
* Thu Nov 22 2007 jdelvare@suse.de
- Drop local changes to sensors-detect that are no longer relevant.
- Drop local changes to sensord.init: we no longer package it.
* Wed Nov 21 2007 jdelvare@suse.de
- Add missing Requires to libsensors3-devel. This is a cosmetic
  change only, as the requirement was already drawn indirectly.
* Mon Nov  5 2007 jdelvare@suse.de
- Add split provides to subpackages libsensors3-devel and sensord
  so that an update will work as designed.
* Fri Nov  2 2007 jdelvare@suse.de
- Fix two rpmlint warnings. One of them was about a missing
  dependency between libsensors3-devel and libsensors3, which was
  breaking the build of other packages.
* Fri Nov  2 2007 jdelvare@suse.de
- Package libsensors separately. I've named the package
  "libsensors3" because it is going to fade out quickly in favor
  of the new, incompatible version from lm-sensors 3.
- Don't remove the build root before installing. rpmlint was
  compaining about that.
* Thu Nov  1 2007 jdelvare@suse.de
- Fix packaging breakage introduced by the following change:
  ppc and ia64 packages do not include isadump nor isaset.
* Wed Oct 31 2007 jdelvare@suse.de
- Package sensord separately.
- Don't include redundant or outdated initalization scripts in
  the documentation tree.
* Sun Oct 28 2007 jdelvare@suse.de
- Update to lm_sensors version 2.10.5
  * Support for the SMSC SCH3112, SCH3114, SCH3116
  * libsensors fixes for the thmc50, bmcsensors, lm93, adm1026
    drivers
  * sensord support for the w83793 and lm87 drivers
  * sensors fixes for the dme1737, thmc50 and adm1021 drivers
  * Detect new Winbond chips
- useful_addresses.html is no longer part of the package.
- lm_sensors-dont-probe-i2c-isa.dif: Drop, bug fixed upstream.
* Mon Oct 15 2007 jdelvare@suse.de
- Do not include i2c tools, they have their own package now.
* Mon Sep  3 2007 jdelvare@suse.de
- Run ldconfig in %%post and %%postun. rpmlint was complaining
  that this was missing.
* Tue Aug 28 2007 werner@suse.de
- Remove hard coded modules introduced by last change
* Tue Aug 14 2007 hvogel@suse.de
- Add sysconfig metadata [#300069]
* Mon Aug 13 2007 jdelvare@suse.de
- Don't probe i2c-isa as a regular i2c bus. This regression was
  introduced in lm_sensors 2.10.4. Fixed upstream in:
  http://www.lm-sensors.org/changeset/4649
* Wed Aug  1 2007 werner@suse.de
- Update to lm_sensors version 2.10.4
  * added support for recent devices and cips like
    dme1737, applesmc, abituguru3, f71882fg, w83627ehf (kernel 2.4)
    support for the w83627ehf VID function
    support for the w83627ehf thermal sensor types
    support for it87 fan4 and fan5
  * support block reads with specified length of I2C devices
  * A lot of fixes and enhancements
  * Add both patches form us for fancontrol and pwmconfig
* Wed Jun 27 2007 jdelvare@suse.de
- Don't package the decode-edid.pl script. It requires parse-edid
  from the read-edid package, which isn't included in Suse.
* Thu Jun 21 2007 dmueller@suse.de
- adjust buildrequires
* Mon Jun  4 2007 jdelvare@suse.de
- Don't build on s390 nor s390x.
* Mon May 28 2007 jdelvare@suse.de
- Fix two rpmlint errors: /etc/init.d/lm_sensors shouldn't be
  marked as a config file, and was missing a Short-Description
  tag.
* Wed May  9 2007 jdelvare@suse.de
- lm_sensors-no-xeon-script.patch: The decode-xeon.pl script is
  outdated. It was never ported to work with 2.6 kernels, so it is
  of no use on recent Suse distributions. Stop shipping it.
- Drop a legacy patch to sensors/main.c related to the
  configuration file name, which is no longer needed.
* Fri May  4 2007 jdelvare@suse.de
- Don't package outdated driver documentation. The up-to-date
  driver documentation is in the kernel-source package.
  (bug #271302)
- Two minor cleanups to the spec file.
* Thu Apr 12 2007 jdelvare@suse.de
- lm_sensors-2.8.3-nodump.patch: Removed, should no longer be
  needed. Since lm_sensors 2.8.6, isadump is only compiled on i386
  and x86_64.
- Likewise, no need to patch prog/dump/isadump.c for powerpc,
  as it won't be compiled for these architectures anyway.
* Thu Apr  5 2007 werner@suse.de
- Update to lm_sensors version 2.10.3 which added support for
  recent devices and support for kernel 2.6.22.
* Thu Mar 29 2007 ro@suse.de
- added bison,flex to buildreq
* Mon Feb 19 2007 werner@suse.de
- Make README.SuSE encoding independend (bug #246130)
* Tue Jan 30 2007 werner@suse.de
- Update to lm_sensors version 2.10.2 which added support for
  recent devices.
* Mon Nov 13 2006 werner@suse.de
- Update to lm_sensors version 2.10.1 which also includes the
  fix for bug #192092 by not overwriting chip settings
- Remove notify warn message from pdb about overwriting settings
* Mon Jun 26 2006 werner@suse.de
- Load i2c-dev kernel module instead of i2c-sensor (bug #188126)
* Tue Feb 28 2006 werner@suse.de
- Update to version 2.10.0 for better udev support (bug #151931)
- Add i2c-0 to static device list for udev (bug #151931)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 werner@suse.de
- Include fan control in lm_sensors service script (bug #141958)
* Tue Dec 13 2005 werner@suse.de
- Do not to handle module variables from package Modules (#137963)
* Thu Nov 10 2005 werner@suse.de
- Add postun section to run insserv_clean (bug #132934)
* Fri Oct 14 2005 werner@suse.de
- Update to lm_sensors version 2.9.2
* Thu Aug 25 2005 werner@suse.de
- Security fix in pwmconfig (bug #112925)
* Wed May 11 2005 schwab@suse.de
- Add freetype2 and libart_lgpl to nfb, needed by rrdtool.
* Mon May  9 2005 werner@suse.de
- Update to lm_sensors-2.9.1
- Use insserv to enable rc script (bug #76174)
* Thu Feb 17 2005 werner@suse.de
- Update to lm_sensors-2.9.0 (bug #50681)
* Mon Aug 30 2004 werner@suse.de
- Update to newest lm_sensors-2.8.7 to be compatible to the current
  kernel version.
* Tue May  4 2004 werner@suse.de
- Fix bug #35502 (missing w83627hf entries) by updating to
  lm_sensors-2.8.6 which includes a better parser for sysfs
* Tue Apr 13 2004 ro@suse.de
- remove kernel-source from neededforbuild
  (not needed any longer)
* Wed Mar 10 2004 werner@suse.de
- Add workaround for missing w83627hf chip driver (bug #35501)
* Tue Mar  9 2004 werner@suse.de
- A few changes for kernel 2.6 (bug #35500)
* Fri Mar  5 2004 pth@suse.de
- Remove no-strict-aliasing and fix the code instead. Patch
  was also sent to upstream maintainers for inclusion.
* Fri Mar  5 2004 ro@suse.de
- added libpng to neededforbuild (for rrdtool)
- use no-strict-aliasing
* Wed Jan 28 2004 ro@suse.de
- update to 2.8.3
- use buildroot and build as user
* Fri Sep 12 2003 ro@suse.de
- configure kernel-source if needed
* Mon Jul 21 2003 werner@suse.de
- Update to lm_sensors 2.8.0
* Thu Jun  5 2003 ro@suse.de
- compile using headers from kernel-source not glibc
* Tue Mar 18 2003 olh@suse.de
- add lm_sensors-2.7.0-nodump.patch to fix dependency tree
* Thu Feb 27 2003 werner@suse.de
- Fix location of sensors program in boot script
* Tue Feb 11 2003 werner@suse.de
- Update due to kernel interface update (anything else is a bug)
* Mon Dec  2 2002 werner@suse.de
- Update to lm_sensors 2.4.6
* Wed Nov  6 2002 werner@suse.de
- Fix bug # 21583: sensors shouldn't segfault on missing argument.
* Wed Sep  4 2002 werner@suse.de
- Fix boot scripts to be usable (bug #18868)
- Install some progs which are described in FAQ
* Wed Aug 28 2002 fehr@suse.de
- updated to current version 2.6.4 of lm_sensors
* Thu Aug  1 2002 werner@suse.de
- Use _libdir macro for 64bit architectures
* Wed Jul 31 2002 werner@suse.de
- Install sensord daemon for logging (bug #17316)
* Tue Jun 18 2002 ke@suse.de
- Fix typo in README.SuSE [# 14790].
* Mon Aug  6 2001 uli@suse.de
- fixed to build on PPC
* Wed Jul  4 2001 werner@suse.de
- update to 2.6.0
* Mon Apr 16 2001 werner@suse.de
- update to 2.5.5
* Thu Apr  5 2001 uli@suse.de
- removed lx_suse from neededforbuild
* Thu Dec 14 2000 werner@suse.de
- Group tag
* Sun Jun 18 2000 ro@suse.de
- update to 2.5.0
* Wed Jun  7 2000 uli@suse.de
- moved docs to %%{_docdir}
* Fri Feb 11 2000 ro@suse.de
- removed requires kernmod (package eliminated)
* Wed Feb  2 2000 werner@suse.de
- No asm/io.h if sys/io.h is included
* Wed Feb  2 2000 werner@suse.de
- No sys/perm.h or sys/io.h on ppc and sparc
* Tue Feb  1 2000 werner@suse.de
- New package sensors (version 2.4.3 corresponds with
  current used kernel i2c patch)
  - Prefix is /usr, mandir is /usr/share/man, and kernel
  includes i2c
  - Be reentrant
  - Use RPM_OPT_FLAGS
  - Install docs of busses, chips and the FAQ
